==> zio-aws-managedblockchain_2.12-5.17.124.2-sources.jar: zio/aws/managedblockchain/model/GetNodeRequest.scala <==
package zio.aws.managedblockchain.model
import zio.aws.managedblockchain.model.primitives.ResourceIdString
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class GetNodeRequest(
    networkId: ResourceIdString,
    memberId: Option[ResourceIdString] = None,
    nodeId: ResourceIdString
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.managedblockchain.model.GetNodeRequest = {
    import GetNodeRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.managedblockchain.model.GetNodeRequest
      .builder()
      .networkId(ResourceIdString.unwrap(networkId): java.lang.String)
      .optionallyWith(
        memberId.map(value => ResourceIdString.unwrap(value): java.lang.String)
      )(_.memberId)
      .nodeId(ResourceIdString.unwrap(nodeId): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.managedblockchain.model.GetNodeRequest.ReadOnly =
    zio.aws.managedblockchain.model.GetNodeRequest.wrap(buildAwsValue())
}
object GetNodeRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.managedblockchain.model.GetNodeRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.managedblockchain.model.GetNodeRequest =
      zio.aws.managedblockchain.model
        .GetNodeRequest(networkId, memberId.map(value => value), nodeId)
    def networkId: ResourceIdString
    def memberId: Option[ResourceIdString]
    def nodeId: ResourceIdString
    def getNetworkId: ZIO[Any, Nothing, ResourceIdString] =
      ZIO.succeed(networkId)
    def getMemberId: ZIO[Any, AwsError, ResourceIdString] =
      AwsError.unwrapOptionField("memberId", memberId)
    def getNodeId: ZIO[Any, Nothing, ResourceIdString] = ZIO.succeed(nodeId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.managedblockchain.model.GetNodeRequest
  ) extends zio.aws.managedblockchain.model.GetNodeRequest.ReadOnly {
    override val networkId: ResourceIdString =
      zio.aws.managedblockchain.model.primitives
        .ResourceIdString(impl.networkId())
    override val memberId: Option[ResourceIdString] = scala
      .Option(impl.memberId())
      .map(value =>
        zio.aws.managedblockchain.model.primitives.ResourceIdString(value)
      )
    override val nodeId: ResourceIdString =
      zio.aws.managedblockchain.model.primitives.ResourceIdString(impl.nodeId())
  }
  def wrap(
      impl: software.amazon.awssdk.services.managedblockchain.model.GetNodeRequest
  ): zio.aws.managedblockchain.model.GetNodeRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-managedblockchain_2.12-5.17.225.1-sources.jar: zio/aws/managedblockchain/model/GetNodeRequest.scala <==
package zio.aws.managedblockchain.model
import zio.aws.managedblockchain.model.primitives.ResourceIdString
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class GetNodeRequest(
    networkId: ResourceIdString,
    memberId: Optional[ResourceIdString] = Optional.Absent,
    nodeId: ResourceIdString
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.managedblockchain.model.GetNodeRequest = {
    import GetNodeRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.managedblockchain.model.GetNodeRequest
      .builder()
      .networkId(ResourceIdString.unwrap(networkId): java.lang.String)
      .optionallyWith(
        memberId.map(value => ResourceIdString.unwrap(value): java.lang.String)
      )(_.memberId)
      .nodeId(ResourceIdString.unwrap(nodeId): java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.managedblockchain.model.GetNodeRequest.ReadOnly =
    zio.aws.managedblockchain.model.GetNodeRequest.wrap(buildAwsValue())
}
object GetNodeRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.managedblockchain.model.GetNodeRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.managedblockchain.model.GetNodeRequest =
      zio.aws.managedblockchain.model
        .GetNodeRequest(networkId, memberId.map(value => value), nodeId)
    def networkId: ResourceIdString
    def memberId: Optional[ResourceIdString]
    def nodeId: ResourceIdString
    def getNetworkId: ZIO[Any, Nothing, ResourceIdString] =
      ZIO.succeed(networkId)
    def getMemberId: ZIO[Any, AwsError, ResourceIdString] =
      AwsError.unwrapOptionField("memberId", memberId)
    def getNodeId: ZIO[Any, Nothing, ResourceIdString] = ZIO.succeed(nodeId)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.managedblockchain.model.GetNodeRequest
  ) extends zio.aws.managedblockchain.model.GetNodeRequest.ReadOnly {
    override val networkId: ResourceIdString =
      zio.aws.managedblockchain.model.primitives
        .ResourceIdString(impl.networkId())
    override val memberId: Optional[ResourceIdString] = zio.aws.core.internal
      .optionalFromNullable(impl.memberId())
      .map(value =>
        zio.aws.managedblockchain.model.primitives.ResourceIdString(value)
      )
    override val nodeId: ResourceIdString =
      zio.aws.managedblockchain.model.primitives.ResourceIdString(impl.nodeId())
  }
  def wrap(
      impl: software.amazon.awssdk.services.managedblockchain.model.GetNodeRequest
  ): zio.aws.managedblockchain.model.GetNodeRequest.ReadOnly = new Wrapper(impl)
}
